/* Basic SASS just for the extension test */

@import vendor

#sass-test
    color: blue
    font-size: 0.3em

    a
        font:
        weight: bold
        family: serif
        &:hover
        background-color: #eee
