@charset "UTF-8";
/*
 * Do direct circular import with "main_circular_2.scss"
 * 
 * Note that this is an error and this file can't be compiled through libsass
 */

@import "main_circular_2";

@import "components/../empty";
